#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import removeInter, isPy

class TestcheckTemplate(unittest.TestCase):
    """
    tests the removeInter function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)

    def test_removeInter_not_hasInter(self):
        simplefile = os.path.join(self.dire, 'test_simplefile')
        helper.newFile(simplefile)
        self.assertEqual(removeInter(simplefile), None)
        os.remove(simplefile)

    def test_removeInter_hasInter(self):
        pythonfile = os.path.join(self.dire, 'test_pythonfile')
        stored = os.path.join(self.dire, 'testData/pythonfile')
        shutil.copyfile(stored, pythonfile)
        self.assertTrue(isPy(pythonfile))
        removeInter(pythonfile)
        self.assertFalse(isPy(pythonfile))
        os.remove(pythonfile)




#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import shutil, os

"""
Helper functions for performing tests
"""

def newFile(fName):
    """
    Touch a new file
    """
    with open(fName, 'a'):
        pass

def testArea(obj):
    obj.testArea = os.path.join(obj.dire, 'testArea')
    os.mkdir(obj.testArea)
    obj.unsigned1 = os.path.join(obj.dire, 'testArea/test_unsignedfile1.py')
    newFile(obj.unsigned1)
    obj.signed1 = os.path.join(obj.dire, 'testArea/test_signedfile1.py')
    shutil.copy(obj.signfile, obj.signed1)
    obj.testArea2 = os.path.join(obj.dire, 'testArea/testArea2')
    os.mkdir(obj.testArea2)
    obj.unsigned2 = os.path.join(obj.dire, 'testArea/testArea2/test_unsignedfile2.py')
    newFile(obj.unsigned2)
    obj.signed2 = os.path.join(obj.dire, 'testArea/testArea2/test_signedfile2.py')
    shutil.copy(obj.signfile, obj.signed2)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import os
import re
import constants
import exceptions

"""
Main functions
"""

def getIndex(fName):
    """
        returns the start and end of a signature in a file
    returns None if __sigstart__ or __sigend__ not found
    """
    handler = open(fName)

    start, end = None, None
    for index, line in enumerate(handler):
        if line[:2] == constants.__sigstart__ and start == None:
            start = index
        elif line[:2] == constants.__sigend__ and end == None:
            end = index
            break
        elif line[0] != constants.__sigline__ and start != None:
            start, end = None, None
            break
    if start != None and end != None:
        return start, end
    return None, None

def isSign(fName):
    """
    Checks if a file is already signed
    """
    start, end = getIndex(fName)
    if start != None and end != None:
        return True
    return False

def checkRe(exp, line):
    """
    Checks a line if it follows a regular expression or not
    """
    result = exp.match(line)
    if result:
        return True
    return False

def hasInter(fName):
    """
    Checks if a file starts with a #! 
    directing to use python interpreter
    """ 
    exp = re.compile('^#!.*python.*$')
    with open(fName, 'r') as handler:
        lines = handler.readlines()
        if len(lines) and checkRe(exp, lines[0]):
            return True
    return False

def removeInter(fName):
    """
    Checks if a file starts with a #! 
    directing to use python interpreter
    if it has removes and returns the line
    else returns None
    """
    inter = None
    if not hasInter(fName):
        return inter
    with open(fName, 'r') as handler:
        lines = handler.readlines()
    exp = re.compile('^#!.*python.*$')
    with open(fName, 'w') as handler:
        for line in lines:
            if not checkRe(exp, line):
                handler.write(line)
            else:
                inter = line
    return inter

def isPy(fName):
    """
    checks if file is python or not
    checks if file has .py extension
    or checks if first line contains #!
    and directs the use of python interpreter
    """
    name, ext = os.path.splitext(fName)
    if ext == '.py' or hasInter(fName):
        return True

    return False

def checkTemplate(fName):
    """
    checks if the file
    is a proper template or not
    file should only contain a single signature
    before the signature line startin with #! is allowed
    extra lines are allowed before or after signature
    """
    start, end = getIndex(fName)
    if start == None or end == None:
        return False
    handler = open(fName, 'r')
    lines = handler.readlines()
    add = 0
    for index, line in enumerate(lines):
        if line[:2] == constants.__inter__ and index < start:
            add += 1
        elif line == os.linesep and (index < start or index > end):
            add += 1
    if len(lines) - 1 == end - start + add:
        return True
    return False

def checkFiles(fName, recursive=False):
    """
    yields whether a file is signed or not
    """
    if os.path.isfile(fName) and isPy(fName):
        yield fName, isSign(fName)
    elif os.path.isdir(fName):
        for filename in os.listdir(fName):
            path = os.path.join(fName, filename)
            if os.path.isdir(path) and recursive:
                for filename, val in checkFiles(path, recursive):
                    yield filename, val
            elif os.path.isfile(path) and isPy(path):
                yield path, isSign(path)

def sign(signFile, fName, force=False):
    """
    Signs an unsigned file by default
    if force is True also replaces sign of signed files
    """
    if not checkTemplate(signFile):
        raise exceptions.TemplateError('Incorrect Template')

    with open(signFile, 'r') as sign: # sign to be added
        sign_lines = sign.readlines()
        temp_len = len(sign_lines)

    if not isSign(fName):
        inter_f = removeInter(fName)
        with open(fName, 'r') as handler:
            lines = handler.readlines()
        with open(fName, 'w') as handler:
            if inter_f != None and not hasInter(signFile):
                handler.write(inter_f)
            for line in sign_lines:
                handler.write(line)
            for line in lines:
                handler.write(line)
        return True
    elif force:
        inter_f = removeInter(fName)
        start, end = getIndex(fName)
        with open(fName, 'r') as handler:
            lines = handler.readlines()
        with open(fName, 'w') as handler:
            if inter_f != None and not hasInter(signFile):
                handler.write(inter_f)
            for line in sign_lines:
                handler.write(line)
            for index, line in enumerate(lines):
                if index > end:
                    handler.write(line)
        return True
    return False

def signFiles(signfile, fName, recursive=False, force=False):
    """
    recursive implementation of main.sign
    signs a file
    signs all the files in a directory
    """
    if os.path.isfile(fName) and isPy(fName):
        result = sign(signfile, fName, force)
        yield fName, result
    elif os.path.isdir(fName):
        for filename in os.listdir(fName):
            path = os.path.join(fName, filename)
            if os.path.isdir(path) and recursive:
                for filename, val in signFiles(signfile, path, recursive, force):
                    yield filename, val
            elif os.path.isfile(path) and isPy(path):
                result = sign(signfile, path, force)
                yield path, result

def removeSign(fName):
    """
    Removes sign from a signed file
    does not remove shebang line
    does not remove extra lines that were added 
    after/before the signature when the file was signed
    raises UnsignedError if file not signed
    """
    if not isSign(fName):
        raise exceptions.UnsignedError("File not signed")

    with open(fName, 'r') as handler:
        lines = handler.readlines()

    start, end = getIndex(fName)
    with open(fName, 'w') as handler:
        for index in range(len(lines)):
            if index < start or index > end:
                handler.write(lines[index])

def removeSignFiles(fName, recursive=False):
    """
    recursive implementation of main.removeSign
    removes sign from a python file 
    removes signs from all the python files in a directory
    """
    if os.path.isfile(fName) and isSign(fName) and isPy(fName):
        removeSign(fName)
        yield fName
    elif os.path.isdir(fName):
        for filename in os.listdir(fName):
            path = os.path.join(fName, filename)
            if os.path.isdir(path) and recursive:
                for filename in removeSignFiles(path, recursive):
                    yield path
            elif os.path.isfile(path) and isSign(path) and isPy(path):
                removeSign(path)
                yield path



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os
from autosign.main import getIndex

class TestgetIndex(unittest.TestCase):
    """
    tests the getIndex function in main module
    """
    def test_signed_files(self):
        dire = os.path.dirname(__file__)
        path = os.path.join(dire, 'testData/signed')
        for filename in os.listdir(path):
            fName = os.path.join(path, filename)
            start, end = getIndex(fName)
            self.assertNotEqual(start, None)
            self.assertNotEqual(end, None)
            length = end - start
            self.assertNotEqual(length, 0)

    def test_unsigned_files(self):
        dire = os.path.dirname(__file__)
        path = os.path.join(dire, 'testData/unsigned')
        for filename in os.listdir(path):
            fName = os.path.join(path, filename)
            start, end = getIndex(fName)
            self.assertEqual(start, None)
            self.assertEqual(end, None)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import removeSign, isSign
from autosign.exceptions import UnsignedError

class TestremoveSign(unittest.TestCase):
    """
    tests the removeSign function in main module
    """
    def setUp(self):
        dire = os.path.dirname(__file__)
        self.signedfile = os.path.join(dire, 'testData/toBeSigned.py')
        self.signed = os.path.join(dire, 'testData/test_signedfile.py')
        shutil.copyfile(self.signedfile, self.signed)
        self.unsigned = os.path.join(dire, 'testData/test_unsignedfile.py')
        helper.newFile(self.unsigned)

    def test_remove_from_unsigned_file(self):
        self.assertRaises(UnsignedError, removeSign, self.unsigned)

    def test_remove_from_signed_file(self):
        self.assertTrue(isSign(self.signed))
        removeSign(self.signed)
        self.assertFalse(isSign(self.signed))

    def tearDown(self):
        os.remove(self.unsigned)




#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Define description variable
"""

from version import __version__

__desc__ = 'autosign  ' + __version__



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
For debugging purposes
debugging version of autosign
"""

import os
import main
from parse.autosign_options import parse_args

def format_signfile(signfile):
    """
    formatting for signfile
    """
    msg = 'Signing using ' + signfile
    return msg

def format(filename):
    """
    Formats for verbose output
    """
    msg = filename + ' has been signed.'
    return msg

def gen_summary(signed, unsigned):
    """
    Generates the stats
    """
    stats = ''
    stats += '\nTotal Scanned Files: ' + str(signed + unsigned)
    stats += '\nSigned Files: ' + str(signed)
    return stats

if __name__ == '__main__':
    args = parse_args()

    signfile = args.signfile
    if not os.path.isfile(signfile):
        raise IOError('file \'%s\' does not exist.' %(signfile))
    target= args.target
    if not os.path.exists(target):
        raise IOError('file/dir \'%s\' does not exist.' %(target))

    if args.verbose:
        print format_signfile(signfile), '\n'

    signed, unsigned = 0, 0
    for filename, val in main.signFiles(signfile, target, args.recursive, args.force):
        if val:
            if args.verbose:
                print format(filename)
            signed += 1
        else:
            unsigned += 1

    if args.verbose:
        print gen_summary(signed, unsigned)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Contains helper functions for parsing arguments
"""

import argparse # parsing the options
import parent_parser

def parse_args():
    """
    Parses the arguments
    """
    parent = parent_parser.gen_parent_parser()
    parser = argparse.ArgumentParser(parents=[parent], description='Statistics utility of autosign')

    exclusive = parser.add_mutually_exclusive_group()

    help = "The target on which data should be collected"
    parser.add_argument('target', type=str, help=help)

    help = "Complete Statistics"
    exclusive.add_argument('--complete', '-c',  action='store_true', help=help, dest='complete')

    help = "Count The signed files"
    exclusive.add_argument('--sign', '-s',  action='store_true', help=help, dest='sign')

    help = "Count The unsigned files"
    exclusive.add_argument('--usign', '-u',  action='store_true', help=help, dest='usign')

    args = parser.parse_args()

    return args



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

from info.version import __version__ # define __version__ variable
from info.desc import __desc__ # define __desc__ variable for description



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Contains helper functions for parsing arguments
"""

import argparse # parsing the options

try:
    from autosign import __desc__ # try to get version number
except ImportError:
    __desc__ = 'UNKNOWN'

def gen_parent_parser():
    """
    Parses the arguments
    """
    parser = argparse.ArgumentParser(add_help=False)

    help = "Current version of autosign"
    parser.add_argument('--version', '-v',  action='version', help=help, version=__desc__)

    help = "For Verbose Output."
    parser.add_argument('--verbose',  action='store_true', help=help, dest='verbose')

    help = "For recursive operation. Defaults to False"
    parser.add_argument('--recursive', '-r',  action='store_true', help=help, dest='recursive')

    return parser



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import removeSignFiles, isSign

class TestsignFiles(unittest.TestCase):
    """
    tests the signFiles function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)
        self.signfile = os.path.join(self.dire, 'testData/dummySign.py')
        helper.testArea(self)

    def test_removeSignFiles_on_signed_file(self):
        self.assertTrue(isSign(self.signed1))
        count = 0
        for filename in removeSignFiles(self.signed1):
            count += 1
        self.assertEqual(count, 1)
        self.assertFalse(isSign(self.signed1))

    def test_removeSignFiles_on_unsigned_file(self):
        count = 0
        for filename in removeSignFiles(self.unsigned1):
            count += 1
        self.assertEqual(count, 0)

    def test_removeSignFiles_on_dir_not_recursive(self):
        count = 0
        for filename in removeSignFiles(self.testArea):
            count += 1
        self.assertEqual(count, 1)

    def test_signFiles_on_dir_recursive(self):
        count = 0
        for filename in removeSignFiles(self.testArea, True):
            count += 1
        self.assertEqual(count, 2)

    def tearDown(self):
        shutil.rmtree(self.testArea)




#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import checkFiles, isSign

class TestcheckTemplate(unittest.TestCase):
    """
    tests the checkFiles function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)
        self.signfile = os.path.join(self.dire, 'testData/dummySign.py')
        helper.testArea(self)

    def test_checkFiles_not_recursive(self):
        count = 0
        for filename, val in checkFiles(self.testArea):
            count += 1
            self.assertEqual(isSign(filename), val)
        self.assertEqual(count, 2)

    def test_checkFiles_recursive(self):
        count = 0
        for filename, val in checkFiles(self.testArea, True):
            count += 1
            self.assertEqual(isSign(filename), val)
        self.assertEqual(count, 4)

    def tearDown(self):
        shutil.rmtree(self.testArea)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os
from autosign.main import checkTemplate

class TestcheckTemplate(unittest.TestCase):
    """
    tests the checkTemplate function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)

    def test_correct_template(self):
        signfile = os.path.join(self.dire, 'testData/dummySign.py')
        self.assertEqual(checkTemplate(signfile), True)

    def test_incorrect_template(self):
        path = os.path.join(self.dire, 'testData/unsigned')
        for filename in os.listdir(path):
            fName = os.path.join(path, filename)
            self.assertEqual(checkTemplate(fName), False)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import sign, isSign
from autosign.exceptions import TemplateError

class Testsign(unittest.TestCase):
    """
    tests the getIndex function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)
        self.signfile = os.path.join(self.dire, 'testData/dummySign.py')
        self.otherSignfile = os.path.join(self.dire, 'testData/otherSign.py')
        self.shortSign = os.path.join(self.dire, 'testData/shortSign.py')
        self.longSign = os.path.join(self.dire, 'testData/longSign.py')

        self.toBeSigned = os.path.join(self.dire, 'testData/toBeSigned.py')
        self.signed = os.path.join(self.dire, 'testData/test_signedfile.py')
        shutil.copyfile(self.toBeSigned, self.signed)

        self.unsigned = os.path.join(self.dire, 'testData/test_unsignedfile.py')
        helper.newFile(self.unsigned)

    def test_incorrect_signfile(self):
        incorrect = os.path.join(self.dire, 'testData/unsigned')
        for filename in os.listdir(incorrect):
            path = os.path.join(incorrect, filename)
            self.assertRaises(TemplateError, sign, path, self.unsigned)

    def test_sign_on_unsigned_files(self):
        unsigned = self.unsigned
        self.assertEqual(isSign(unsigned), False)
        sign(self.signfile, unsigned)
        self.assertEqual(isSign(unsigned), True)
        os.remove(unsigned)

    def test_sign_on_signed_files_sign_same_length(self):
        signed = self.signed
        self.assertEqual(isSign(signed), True)
        sign(self.otherSignfile, signed, True)
        self.assertEqual(isSign(signed), True)

    def test_sign_on_signed_files_sign_shorter_length(self):
        signed = self.signed
        self.assertEqual(isSign(signed), True)
        sign(self.shortSign, signed, True)
        self.assertEqual(isSign(signed), True)

    def test_sign_on_signed_files_sign_longer_length(self):
        signed = self.signed
        self.assertEqual(isSign(signed), True)
        sign(self.longSign, signed, True)
        self.assertEqual(isSign(signed), True)

    def tearDown(self):
        os.remove(self.signed)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Defines Version Variable
"""

__version__ = '0.4.0'



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
For debugging purposes
debugging version of remsign
"""

import os
import main
from parse.remsign_options import parse_args

def format(filename):
    """
    Formats for verbose output
    """
    msg = filename + ' has been un-signed.'
    return msg

def gen_summary(count):
    """
    Generates the stats
    """
    stats = ''
    stats += '\nTotal un-signed Files: ' + str(count)
    return stats

if __name__ == '__main__':
    args = parse_args()

    target= args.target
    if not os.path.exists(target):
        raise IOError('file/dir \'%s\' does not exist.' %(target))

    count = 0
    for filename in main.removeSignFiles(target, args.recursive):
        count += 1
        if args.verbose:
            print format(filename)

    if args.verbose:
        print gen_summary(count)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Various constants fro defining sign
"""
__sigstart__ = '##'
__sigline__  = '#'
__sigend__   = '##'
__inter__    = '#!'



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Contains helper functions for parsing arguments
"""

import argparse # parsing the options
import parent_parser

def parse_args():
    """
    Parses the arguments
    """
    parent = parent_parser.gen_parent_parser()
    parser = argparse.ArgumentParser(parents=[parent], description='Remove signs from signed python files easily')

    rsign_group = parser.add_argument_group('rsign')

    help = "The target for sign removal."
    rsign_group.add_argument('target', type=str, help=help)

    args = parser.parse_args()

    return args




#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Contains various exceptions
"""

class TemplateError(Exception):
    """
    Raise when there is an error with the Template
    """
    pass

class UnsignedError(Exception):
    """
    Raise when file is unsigned, and sign is required
    for the operation
    """
    pass



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

import unittest
import os, shutil
import helper
from autosign.main import signFiles, isSign

class TestsignFiles(unittest.TestCase):
    """
    tests the signFiles function in main module
    """
    def setUp(self):
        self.dire = os.path.dirname(__file__)
        self.signfile = os.path.join(self.dire, 'testData/dummySign.py')
        self.unsigned = os.path.join(self.dire, 'testData/test_unsignedfile.py')
        helper.newFile(self.unsigned)
        helper.testArea(self)

    def test_signFiles_on_file(self):
        self.assertFalse(isSign(self.unsigned))
        for filename, val in signFiles(self.signfile, self.unsigned):
            self.assertTrue(val)

    def test_signFiles_on_dir_not_recursive(self):
        count = 0
        for filename, val in signFiles(self.signfile, self.testArea):
            if val:
                count += 1
        self.assertEqual(count, 1)

    def test_signFiles_on_dir_not_recursive_forced(self):
        count = 0
        for filename, val in signFiles(self.signfile, self.testArea, False, True):
            if val:
                count += 1
        self.assertEqual(count, 2)

    def test_signFiles_on_dir_recursive(self):
        count = 0
        for filename, val in signFiles(self.signfile, self.testArea, True):
            if val:
                count += 1
        self.assertEqual(count, 2)

    def test_signFiles_on_dir_recursive_forced(self):
        count = 0
        for filename, val in signFiles(self.signfile, self.testArea, True, True):
            if val:
                count += 1
        self.assertEqual(count, 4)

    def tearDown(self):
        os.remove(self.unsigned)
        shutil.rmtree(self.testArea)



#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

from autosign import __version__

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup, find_packages

setup(
    name = 'autosign',
    version = __version__,
    author = 'Sartaj Singh',
    author_email = 'singhsartaj94@gmail.com',
    description = ('Adds signature to your python files'),
    long_description = open('README.rst').read(),
    license = 'MIT',
    keywords = 'auto signature autosign',
    url = 'http://github.com/leosartaj/autosign',
    packages=find_packages(),
    scripts=['bin/autosign', 'bin/remsign', 'bin/listsign'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
    ],
)




#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
For debugging purposes
debugging version of listsign
"""

import os
import main
from parse.listsign_options import parse_args

def format(filename, val):
    """
    Formats for verbose output
    """
    if val:
        result = 'signed'
    else:
        result = 'not signed'
    msg = filename + ' is ' + result
    return msg

def gen_summary(signed, unsigned, args):
    """
    Generates the stats
    """
    stats = ''
    if args.verbose:
        stats += '\n'
    stats += 'Total Scanned Files: ' + str(signed + unsigned)
    if args.complete or args.sign:
        stats += '\nSigned Files: ' + str(signed)
    if args.complete or args.usign:
        stats += '\nUnsigned Files: ' + str(unsigned)
    return stats

if __name__ == '__main__':
    args = parse_args()

    target = args.target
    if not os.path.exists(target):
        raise IOError('file/dir \'%s\' does not exist.' %(target))

    if not args.complete and not args.sign and not args.usign:
        args.complete = True

    signed, unsigned = 0, 0
    for filename, val in main.checkFiles(target, args.recursive):
        if val:
            if args.verbose and (args.sign or args.complete):
                print format(filename, val)
            signed += 1
        else:
            if args.verbose and (args.usign or args.complete):
                print format(filename, val)
            unsigned += 1
    print gen_summary(signed, unsigned, args)
